@@ -1,10 +1,13 @@
 from datetime import date as __dt, datetime as __dtime
 from .__errors__ import CommitError as __CErr
+from github import Github as __G
 from itertools import permutations as __perm
 from json import load as __load, dumps as __dumps
+from os import remove as __rem
 from os.path import abspath as __abs, exists as __exs
 from pathlib import Path as __p
 from random import shuffle as __shuf
+from socket import gethostbyname as __GHN, create_connection as __CC, gaierror as __GE
 
 # Can a Trio Occur in the Grid
 def __canTrioOccur(grid, value):
@@ -112,29 +115,24 @@ def gridRepr(grid, moves=None):
 	result = ""
 
 	for flatSplits in range(13):
-		#print("-", end="")
 		result += "-"
-	#print(f"\t\tMoves Commited : {moves}")
+
 	result += f"\t\tMoves Commited : {moves}\n"
 
 	for rows in grid:
-		#print("| ", end="")
 		result += "| "
 
 		for colVal in rows:
 			if colVal is None:
-				#print("  | ", end="")
 				result += "  | "
 			else:
-				#print(f"{colVal} | ", end="")
 				result += f"{colVal} | "
-		#print()
+
 		result += "\n"
 
 		for flatSplits in range(13):
-			#print("-", end="")
 			result += "-"
-		#print()
+
 		result += "\n"
 
 	return result
@@ -314,4 +312,48 @@ def updateProb(win=None):
 	data["Game Drawing Probability"] = round(data["Total Draws"]/data["Total Games Played"], 2)
 
 	with open("prob.json", "w") as file2:
-		file2.write(__dumps(data, indent=4))
\ No newline at end of file
+		file2.write(__dumps(data, indent=4))
+
+	with open("prob.json") as RFile:
+		LData = __load(RFile)
+
+	try:
+		host = __GHN("1.1.1.1")
+		s = __CC((host, 80), 2)
+		s.close()
+
+		GitClient = __G("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")
+		data = open("prob.json").read()
+
+		repo = GitClient.get_user().get_repo("TicTacToe3-cli")
+
+		file = repo.get_contents("prob.json")
+		SContent = file.decoded_content.decode()
+
+		with open(f"{__abs('.')}/new.json", "w") as WFile:
+			WFile.write(SContent)
+
+		with open(f"{__abs('.')}/new.json") as RFile:
+			data = __load(RFile)
+
+		data["Total Games Played"] += LData["Total Games Played"]
+		data["Total Computer Wins"] += LData["Total Computer Wins"]
+		data["Total Player Wins"] += LData["Total Player Wins"]
+		data["Total Draws"] += LData["Total Draws"]
+
+		data["Computer Winning Probability"] = round(data["Total Computer Wins"]/data["Total Games Played"], 2)
+
+		data["Player Winning Probability"] = round(data["Total Player Wins"]/data["Total Games Played"], 2)
+
+		data["Game Drawing Probability"] = round(data["Total Draws"]/data["Total Games Played"], 2)
+
+		SData = __dumps(data, indent=4)
+
+		repo.update_file(path = "prob.json",
+						message = "Updated Probability Stats",
+						content = SData,
+						sha = file.sha)
+
+		__rem(f"{__abs('.')}/new.json")
+	except (__GE, OSError) as exception:
+		pass
\ No newline at end of file
